@@ -12,30 +12,29 @@ import bpy
 import pandas as pd
 
 class init_anim:
+    """
+    Sets up the global animation information such speed up and global scale
+
+
+    Arguments:
+        :param t: :class:`~np.ndarray', contains the time information that corresponds with the six degrees of freedom data 
+        :param speed_up: float, the "real time speed up" or the ratio of the duration of the data to the duration of the animation 
+        :param scale: float, global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
+
+    """
     def __init__(self, t, speed_up, scale):
 
-        """
-        .. Sets up the global animation information such speed up and global scale
-
-
-        Arguments:
-            :param t (nd.array): contains the time information that corresponds with the six degrees of freedom data 
-            :param speed_up (float): the "real time speed up" or the ratio of the duration of the data to the duration of the animation 
-            :param scale (float): global physical scale factor of the animation, i.e., .1 will reduce everything to be 1/10th its original size
-
-        """
-
         self.frame_rate = bpy.context.scene.render.fps
         """float: frame rate of animation"""
         
         self.t = t
-        """iterable[float]: contains the time information that corresponds with the six degrees of freedom data"""
+        """:class:`~np.ndarray': contains the time information that corresponds with the six degrees of freedom data"""
         
         self.speed_up = speed_up
         """float: the "real time speed up" or the ratio of the duration of the data to the duration of the animation"""
         
         self.frames = np.linspace(1, int(t[-1]*self.frame_rate/speed_up+1), len(t)).astype(int)
-        """iterable[float]: the frames that Blender will animate and have corresponding data for"""
+        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
         
         self.frame_duration = self.frames[-1]
         """int: number of total frames in animation"""
@@ -47,27 +46,28 @@ class init_anim:
         bpy.context.scene.frame_end = self.frame_duration+1
 
 class ref_frame:
+    """
+    Initializes a reference frame that other objects and animations can be the child of. 
+
+    In blender, this takes the form of an Empty object.
+
+
+    Arguments:
+        :param name: str, the Blender object name of the reference frame
+        :param parent: :class:`~bpy.data.object', the Blender object parent of this reference frame 
+        :param anim: :class:`~bpsci.core.init_anim`), class object that was used to initialize the animation
+
+    """
     def __init__(self, name, parent, anim):
-        """
-        .. Initializes a reference frame that other objects and animations can be the child of. 
-
-        In blender, this takes the form of an Empty object.
-
-
-        Arguments:
-            :param name (str): the Blender object name of the reference frame
-            :param parent (bpy.data.object): the Blender object parent of this reference frame 
-            :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
-
-        """
+        
         self.name = name
         """str: the Blender object name of the reference frame"""
         self.parent = parent
-        """bpy.data.object: the Blender object parent of this reference frame"""
+        """:class:`~bpy.data.object': the Blender object parent of this reference frame"""
         
         # Blender portion
         self.ob = bpy.data.objects.new(name, None)
-        """bpy.data.object: the Blender object that represents this reference frame"""
+        """:class:`~bpy.data.object': the Blender object that represents this reference frame"""
         
         bpy.context.scene.collection.objects.link(self.ob)
         
@@ -76,7 +76,7 @@ class ref_frame:
         self.ob.rotation_mode = 'QUATERNION'
 
         self.frames = anim.frames
-        """iterable[float]: the frames that Blender will animate and have corresponding data for"""
+        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
 
         self.scale = anim.scale
         """float: global physical scale factor of the animation"""
@@ -84,7 +84,7 @@ class ref_frame:
         
     def static_6DOF(self, quat, x, y, z):
         """
-        .. Places the reference frame in one specified static location.
+        Places the reference frame in one specified static location.
 
         .. warning::
             This is currently an internal method. This method will be exposed properly in future updates
@@ -94,10 +94,10 @@ class ref_frame:
 
 
         Arguments:
-            :param quat (nd.array): an numpy array of one quaternion
-            :param x (float): the x position 
-            :param y (float): the y position 
-            :param z (float): the z position 
+            :param quat: :class:`~np.ndarray', an numpy array of one quaternion
+            :param x: float, the x position 
+            :param y: float, the y position 
+            :param z: float, the z position 
 
         """
         if not(quat is None):
@@ -112,7 +112,7 @@ class ref_frame:
         
     def dynamic_6DOF(self, quat, x_list, y_list, z_list):
         """
-        .. Animates the reference frame over time.
+        Animates the reference frame over time.
 
         .. warning::
             This is currently an internal method. This method will be exposed properly in future updates
@@ -122,10 +122,10 @@ class ref_frame:
 
 
         Arguments:
-            :param quat (nd.array): an numpy array of quaternions over time
-            :param x (nd.array): the x position over time
-            :param y (nd.array): the y position over time
-            :param z (nd.array): the z position over time
+            :param quat: :class:`~np.ndarray', an numpy array of quaternions over time
+            :param x: :class:`~np.ndarray', the x position over time
+            :param y: :class:`~np.ndarray', the y position over time
+            :param z: :class:`~np.ndarray', the z position over time
 
         """
 
@@ -156,36 +156,35 @@ class ref_frame:
         
 
 class dyn_obj:
+    """
+    The main building block of all dynamic visualizations 
+
+    Arguments:
+        :param obj: :class:`~bpy.data.object', the Blender object that will be animated
+        :param pa: :class:`~np.ndarray', the offset of the principal axes specified by the :param euler_type:
+        :param euler_type: str. the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
+        :param parent: :class:`~bpy.data.object', the Blender object parent of the original object 
+        :param anim: :class:`~bpsci.core.init_anim`, class object that was used to initialize the animation
+
+    """
     def __init__(self, obj, pa, euler_type, parent, anim):
 
-        """
-        .. The main building block of all dynamic visualizations 
-
-        Arguments:
-            :param obj (bpy.data.object): the Blender object that will be animated
-            :param pa (iterable[float]): the offset of the principal axes specified by the :param euler_type:
-            :param euler_type (str): the Euler angle order (i.e. 'xyz' for 1,2,3 or 'zxz' for 3,1,3)
-            :param parent (bpy.data.object): the Blender object parent of the original object 
-            :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
-
-        """
-
         self.parent = parent
-        """bpy.data.object: the Blender object parent of this reference frame"""
+        """:class:`~bpy.data.object': the Blender object parent of this reference frame"""
 
         self.frames = anim.frames
-        """iterable[float]: the frames that Blender will animate and have corresponding data for"""
+        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
         self.scale = anim.scale
         """float: global physical scale factor of the animation"""
 
         self.ob = obj
-        """bpy.data.object: the Blender object that will be animated"""
+        """:class:`~bpy.data.object': the Blender object that will be animated"""
         
         self.euler_pa = pa
-        """iterable[float]: the offset of the principal axes specified by the :param euler_type:"""
+        """:class:`~np.ndarray': the offset of the principal axes specified by the :param euler_type:"""
         
         self.quat = R.from_euler(euler_type, pa).as_quat()
-        """nd.array: a numpy array of one quaternion that represents the principal axes offset"""
+        """:class:`~np.ndarray': a numpy array of one quaternion that represents the principal axes offset"""
         
         self.non_rot = ref_frame(obj.name+'_non_rot', parent, anim)
         """:class:`~bpsci.core.ref_frame`: the non-rotational reference frame (owner of translational movement only)"""
@@ -209,34 +208,34 @@ class dyn_obj:
     def apply_animation(self, x_list, y_list, z_list, quat_list):
 
         """
-        .. Animates a :class:`~bpsci.core.dyn_obj` in the full six degrees of freedom
+        Animates a :class:`~bpsci.core.dyn_obj` in the full six degrees of freedom
 
         Arguments:
-        :param x_list (nd.array): a numpy array of the x position over time
-        :param y_list (nd.array): a numpy array of the y position over time
-        :param z_list (nd.array): a numpy array of the z position over time
-        :param quat_list (nd.array or None): a numpy array of the rotational quaternion over time. Can be passed None if rotation is ignored.
-        """
+            :param x_list: :class:`~np.ndarray', a numpy array of the x position over time
+            :param y_list: :class:`~np.ndarray', a numpy array of the y position over time
+            :param z_list: :class:`~np.ndarray'. a numpy array of the z position over time
+            :param quat_list: :class:`~np.ndarray' or None, a numpy array of the rotational quaternion over time. Can be passed None if rotation is ignored.
+            """
 
         self.pa_axes.dynamic_6DOF(quat_list, None, None, None)
         self.non_rot.dynamic_6DOF(None, x_list, y_list, z_list)
 
     def apply_streamline(self, staticity, int_x, int_y, int_z, thickness):
         """
-        .. Creates a static or dynamic positional streamline for a :class:`~bpsci.core.dyn_obj`
+        Creates a static or dynamic positional streamline for a :class:`~bpsci.core.dyn_obj`
 
         Arguments:
             :param staticity (str): a string (either 'static' or 'dynamic') that specifies whether the the streamline is animated over time
-            :param int_x (nd.array): a numpy array of the x position over time
-            :param int_y (nd.array): a numpy array of the y position over time
-            :param int_z (nd.array): a numpy array of the z position over time
+            :param int_x: :class:`~np.ndarray', a numpy array of the x position over time
+            :param int_y: :class:`~np.ndarray', a numpy array of the y position over time
+            :param int_z: :class:`~np.ndarray', a numpy array of the z position over time
         """
 
 
         name = self.name+'_streamline'
         """str: the Blender object name of the streamline"""
         frames = self.frames
-        """iterable[float]: the frames that Blender will animate and have corresponding data for"""
+        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
         
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
@@ -276,28 +275,27 @@ class dyn_obj:
 
 
 class dyn_vec:
+    """
+    Initializes a dynamic vector`
+
+    Arguments:
+        :param parent: :class:`~bpy.data.object', the Blender object the vector is associated with
+        :param name: str, the Blender object name of the vector ('_vector' will be appended to this name)
+        :param scale_mag: float, the scaling factor of the vector's magnitude axis (purely aesthetic)
+        :param scale_off: float, the scaling factor of the vector's off-axes (purely aesthetic)
+        :param offset: tuple[float], offset of vector from the parent object (purely aesthetic)
+        :param anim: :class:`~bpsci.core.init_anim`, class object that was used to initialize the animation
+    """
     def __init__(self, parent, name, scale_mag, scale_off, offset, anim):
-        """
-        .. Initializes a dynamic vector`
-
-        Arguments:
-            :param parent (bpy.data.object): the Blender object the vector is associated with
-            :param name (str): the Blender object name of the vector ('_vector' will be appended to this name)
-            :param scale_mag (float): the scaling factor of the vector's magnitude axis (purely aesthetic)
-            :param scale_off (float): the scaling factor of the vector's off-axes (purely aesthetic)
-            :param offset (tuple[float]): offset of vector from the parent object (purely aesthetic)
-            :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
-        """
-
 
         self.parent = parent
-        """bpy.data.object: the Blender object parent of this reference frame"""
+        """:class:`~bpy.data.object': the Blender object parent of this reference frame"""
 
         self.name = name+"_vector"
         """str: the Blender object name of the vector"""
         
         self.parent_rf = ref_frame(self.name+"_empty", self.parent, anim)
-        """bpy.data.object: holds the vector"""
+        """:class:`~bpy.data.object': holds the vector"""
 
         self.filepath = self.filepath = __file__.replace("__init__.py", "").replace("\\core.py", "")+'\\assets\\objects\\arrow.obj' #"C:/Users/vargh/Documents/GitHub/bpsci/bpsci/assets/objects/arrow.obj" #bpsci.__file__.replace("__init__.py", "")+'\\assets\\objects\\arrow.obj'
         """str: file path to arrow asset"""
@@ -306,7 +304,7 @@ class dyn_vec:
         vec = bpy.ops.import_scene.obj(filepath=self.filepath)
         vec = bpy.context.selected_objects[0]
         self.vec = vec
-        """bpy.data.object: the actual arrow asset"""
+        """:class:`~bpy.data.object': the actual arrow asset"""
         
         self.parent_rf.ob.location = offset
         vec.parent = self.parent_rf.ob
@@ -318,15 +316,15 @@ class dyn_vec:
         """:class:`~bpsci.core.init_anim`: class object that was used to initialize the animation"""
         
         self.frames = anim.frames
-        """iterable[float]: the frames that Blender will animate and have corresponding data for"""
+        """:class:`~np.ndarray': the frames that Blender will animate and have corresponding data for"""
     def animate(self, x, y, z):
         """
-        .. Animates a dynamic vector
+        Animates a dynamic vector
 
         Arguments:
-        :param x (nd.array): a numpy array of the x component over time
-        :param y (nd.array): a numpy array of the y component over time
-        :param z (nd.array): a numpy array of the z component over time
+        :param x: :class:`~np.ndarray', a numpy array of the x component over time
+        :param y: :class:`~np.ndarray',  a numpy array of the y component over time
+        :param z: :class:`~np.ndarray', a numpy array of the z component over time
         """
 
         frames = self.frames
@@ -347,7 +345,7 @@ class dyn_vec:
         norm_z = z/max_z *self.scale
         
         self.point_rf = ref_frame(self.name+"_pointing_empty", self.parent, self.anim)
-        """bpy.data.object: an empty that provides calculates the directionality of the vector"""
+        """:class:`~bpy.data.object': an empty that provides calculates the directionality of the vector"""
         
         tracking_constraint = self.parent_rf.ob.constraints.new('DAMPED_TRACK')
         tracking_constraint.target = self.point_rf.ob
@@ -369,19 +367,20 @@ class dyn_vec:
             self.parent_rf.ob.keyframe_insert(data_path='scale', frame=cur_frame)
 
 class anim_text:
-    def __init__(self, name, parent, anim, data, label, fix_place, if_str):
-        """
-        .. Creates animated text
+    """
+    Creates animated text
 
-        Arguments:
-        :param name (str): the Blender object name of the text ('_text' will be appended to this name)
-        :param parent (bpy.data.object): the Blender object parent of this text 
-        :param anim (:class:`~bpsci.core.init_anim`): class object that was used to initialize the animation
-        :param data (nd.array): the data to be displayed (same length as the number of animated frames)
-        :param label (str): a label to append to the text (if no label is desired, pass '')
-        :param fix_place (int): the number of decimal places to fix the text to
-        :param if_str (bool): whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
-        """
+    Arguments:
+        :param name: str, the Blender object name of the text ('_text' will be appended to this name)
+        :param parent: :class:`~bpy.data.object', the Blender object parent of this text 
+        :param anim: :class:`~bpsci.core.init_anim`, class object that was used to initialize the animation
+        :param data: :class:`~np.ndarray', the data to be displayed (same length as the number of animated frames)
+        :param label: str, a label to append to the text (if no label is desired, pass '')
+        :param fix_place: int, the number of decimal places to fix the text to
+        :param if_str: bool, whether or not the data is a numerical or string vector. Currently only numerical vectors are supported.
+    """
+    def __init__(self, name, parent, anim, data, label, fix_place, if_str):
+        
 
         self.anim = anim
 
